# Don't generate requires on jpackage-utils and java-headless for
# provided pseudo-artifacts: com.sun:tools and sun.jdk:jconsole.
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}/maven-metadata/javapackages-metadata.xml$

# Disable automatic bytecode compilation for files in java-utils
# https://fedoraproject.org/wiki/Packaging:Python_Appendix#Manual_byte_compilation
%global _python_bytecompile_extra 0

%bcond_without asciidoc
%bcond_with gradle
%bcond_without tests
%bcond_without xmvn_javadoc

%global python_prefix python3
%global python_interpreter %{?__python3}%{!?__python3:dummy}

%global default_jdk %{?_root_prefix}%{!?_root_prefix:%{_prefix}}/lib/jvm/java-11-openjdk
%global default_jre %{?_root_prefix}%{!?_root_prefix:%{_prefix}}/lib/jvm/jre-11-openjdk

Name:           javapackages-tools
Version:        5.3.0
Release:        %mkrel 14
Group:          Development/Java

Summary:        Macros and scripts for Java packaging support

License:        BSD
URL:            https://github.com/fedora-java/javapackages
Source0:        https://github.com/fedora-java/javapackages/archive/%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  coreutils
BuildRequires:  which
BuildRequires:  make
%if %{with asciidoc}
BuildRequires:  asciidoc
BuildRequires:  xmlto
%endif
BuildRequires:  %{python_prefix}-devel
BuildRequires:  %{python_prefix}-lxml
BuildRequires:  %{python_prefix}-setuptools
%if !0%{?_module_build}
# XXX python-nose is not part of any module yet, but it should get
# modularized one day, right?  mizdebsk, Sep 2017
BuildRequires:  %{python_prefix}-nose
%endif
BuildRequires:  %{python_prefix}-six

Requires:       javapackages-filesystem = %{version}-%{release}
Requires:       coreutils
Requires:       findutils
Requires:       which
# default JRE
Requires:       java-11-openjdk-headless

Provides:       jpackage-utils = %{version}-%{release}
# These could be generated automatically, but then we would need to
# depend on javapackages-local for dependency generator.
Provides:       mvn(com.sun:tools) = SYSTEM
Provides:       mvn(sun.jdk:jconsole) = SYSTEM

%description
This package provides macros and scripts to support Java packaging.

%package -n javapackages-filesystem
Summary:        Java packages filesystem layout
Obsoletes:      eclipse-filesystem < 2
Provides:       eclipse-filesystem = %{version}-%{release}

%description -n javapackages-filesystem
This package provides some basic directories into which Java packages
install their content.

%package -n maven-local
Summary:        Macros and scripts for Maven packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       xmvn-minimal
Requires:       xmvn-mojo
Requires:       xmvn-connector-aether
# Common Maven plugins required by almost every build. It wouldn't make
# sense to explicitly require them in every package built with Maven.
Requires:       mvn(org.apache.maven.plugins:maven-compiler-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-jar-plugin)
%if %{without xmvn_javadoc}
Requires:       mvn(org.apache.maven.plugins:maven-javadoc-plugin)
%endif
Requires:       mvn(org.apache.maven.plugins:maven-resources-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-surefire-plugin)
# Tests based on JUnit are very common and JUnit itself is small.
# Include JUnit and JUnit provider for Surefire just for convenience.
Requires:       mvn(junit:junit)
Requires:       mvn(org.apache.maven.surefire:surefire-junit4)
# testng is quite common as well
Requires:       mvn(org.apache.maven.surefire:surefire-testng)

%description -n maven-local
This package provides macros and scripts to support packaging Maven artifacts.

%if %{with gradle}
%package -n gradle-local
Summary:        Local mode for Gradle
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       gradle >= 2.2.1-2
Requires:       xmvn-connector-gradle

%description -n gradle-local
This package implements local mode for Gradle, which allows artifact
resolution using XMvn resolver.
%endif

%package -n ivy-local
Summary:        Local mode for Apache Ivy
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       apache-ivy >= 2.3.0-8
Requires:       xmvn-connector-ivy

%description -n ivy-local
This package implements local mode for Apache Ivy, which allows
artifact resolution using XMvn resolver.

%package -n %{python_prefix}-javapackages
Summary:        Module for handling various files for Java packaging
Requires:       %{python_prefix}-lxml
Requires:       %{python_prefix}-six
Obsoletes:      python-javapackages < %{version}-%{release}

%description -n %{python_prefix}-javapackages
Module for handling, querying and manipulating of various files for Java
packaging in Linux distributions

%package -n javapackages-local
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       xmvn-install
Requires:       xmvn-subst
Requires:       xmvn-resolve
# Java build systems don't have hard requirement on java-devel, so it should be there
Requires:       java-11-openjdk-devel
Requires:       %{python_prefix}-javapackages = %{version}-%{release}
Requires:       %{python_interpreter}
Provides:       javapackages-generators

%description -n javapackages-local
This package provides non-essential macros and scripts to support Java packaging.

%prep
%setup -q -n javapackages-%{version}

%if %{without asciidoc}
sed -i '/^manpage /d' build
sed -i '/${mandir}/d' install
%endif

%build
%configure --pyinterpreter=%{python_interpreter} \
    --default_jdk=%{default_jdk} --default_jre=%{default_jre} \
    --rpmmacrodir=%{_rpmmacrodir}
./build

%install
./install

%if %{with xmvn_javadoc}
sed -i 's|mvn_build.py|& --xmvn-javadoc|' $(find %{buildroot} -name 'macros*.fjava')
%endif
sed -e 's/.[17]$/&*/' -i files-*

%if %{without gradle}
rm -rf %{buildroot}%{_bindir}/gradle-local
rm -rf %{buildroot}%{_datadir}/gradle-local
rm -rf %{buildroot}%{_mandir}/man7/gradle_build.7
%endif

# (tv) fix conflicts with rpm:
perl -pi -e 'undef $_ if m!dir /usr/lib/rpm/fileattrs!' files-local

%if %{with tests}
%if !0%{?_module_build}
%check
./check
%endif
%endif

%files -f files-tools

%files -n javapackages-filesystem -f files-filesystem

%files -n javapackages-local -f files-local

%files -n maven-local

%if %{with gradle}
%files -n gradle-local -f files-gradle
%endif

%files -n ivy-local -f files-ivy

%files -n %{python_prefix}-javapackages -f files-python
%license LICENSE




%changelog
* Sun Jan 03 2021 neoclust <neoclust> 5.3.0-14.mga8
+ Revision: 1668521
- Add javapackages-generators provides

* Tue Aug 18 2020 neoclust <neoclust> 5.3.0-10.mga8
+ Revision: 1615070
- Fix rpmmacrodir definition

* Tue Aug 18 2020 neoclust <neoclust> 5.3.0-9.mga8
+ Revision: 1614796
- Use java11 by default

* Sun Feb 16 2020 umeabot <umeabot> 5.3.0-8.mga8
+ Revision: 1531645
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Sep 14 2019 daviddavid <daviddavid> 5.3.0-7.mga8
+ Revision: 1440700
- rebuild for python3.8

* Mon Jan 07 2019 daviddavid <daviddavid> 5.3.0-6.mga7
+ Revision: 1351111
- rebuild for new Python 3.7

* Fri Dec 14 2018 neoclust <neoclust> 5.3.0-5.mga7
+ Revision: 1341182
- Sync with fc29

* Tue Oct 09 2018 guillomovitch <guillomovitch> 5.3.0-4.mga7
+ Revision: 1319134
- disable xmvn_javadoc again

* Sat Oct 06 2018 guillomovitch <guillomovitch> 5.3.0-3.mga7
+ Revision: 1318239
- use builtin javadoc support

* Fri Oct 05 2018 wally <wally> 5.3.0-2.mga7
+ Revision: 1318025
- disable debug pkg
- make main pkg archfull
+ guillomovitch <guillomovitch>
- add back eclipse patch

* Wed Oct 03 2018 guillomovitch <guillomovitch> 5.3.0-1.mga7
+ Revision: 1317277
- new version 5.3.0

* Sun Sep 23 2018 umeabot <umeabot> 5.0.0-6.mga7
+ Revision: 1298357
- Mageia 7 Mass Rebuild

* Wed Aug 15 2018 wally <wally> 5.0.0-5.mga7
+ Revision: 1251771
- main pkg can't be noarch as it relies on %%_libdir
- add patch to fix eclipse.conf as our eclipse platform root dir is still %%_libdir/eclipse instead of %%_prefix/lib/eclipse

* Sun Feb 11 2018 daviddavid <daviddavid> 5.0.0-4.mga7
+ Revision: 1200494
- Conditionally allow building without asciidoc

* Fri Sep 01 2017 daviddavid <daviddavid> 5.0.0-3.mga7
+ Revision: 1150451
- Fix traceback on corrupt zipfile
- Resolves: rhbz#1481005
- Conditionalize use of XMvn Javadoc MOJO

* Mon Aug 07 2017 daviddavid <daviddavid> 5.0.0-2.mga7
+ Revision: 1138279
- fix again conflict with rpm

* Sat Aug 05 2017 daviddavid <daviddavid> 5.0.0-1.mga7
+ Revision: 1135087
- sync with fedora 27
+ tv <tv>
- new release

* Thu Aug 03 2017 philippem <philippem> 4.7.0-6.2.mga7
+ Revision: 1134428
- disable manualy check
- bootstrap
- rebuild for Python 3.6

* Sun May 07 2017 neoclust <neoclust> 4.7.0-6.1.mga7
+ Revision: 1099554
- Rebuild against new xmvn

* Sun Nov 27 2016 daviddavid <daviddavid> 4.7.0-2.mga6
+ Revision: 1070450
- Add Requires on which (rhbz#1396395)

* Thu Apr 21 2016 tv <tv> 4.7.0-1.mga6
+ Revision: 1003969
- new release
- new release

* Thu Feb 25 2016 neoclust <neoclust> 4.6.0-5.mga6
+ Revision: 978920
- Move mvn_build and builddep to javapackages-local

* Sat Dec 26 2015 daviddavid <daviddavid> 4.6.0-4.mga6
+ Revision: 915358
- do a non bootstrap build

* Mon Dec 21 2015 tv <tv> 4.6.0-3.mga6
+ Revision: 913096
- fix conflict with rpm

* Mon Dec 21 2015 tv <tv> 4.6.0-2.mga6
+ Revision: 912977
- unbreak BS
- simplify

* Mon Dec 21 2015 neoclust <neoclust> 4.6.0-1.mga6
+ Revision: 912809
- Add bootstrap option
+ zezinho <zezinho>
- new version

* Sat Jul 25 2015 daviddavid <daviddavid> 4.1.0-16.mga6
+ Revision: 857176
- add Patch6 from Fedora to fix missing space between xmlns declarations

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-15.mga5
+ Revision: 806058
- Clean rebuild
- Fix a conflict with rpm

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-13.mga5
+ Revision: 806046
- Restore wrongly dropped epoch
+ dmorgan <dmorgan>
- Fix Requires

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-11.mga5
+ Revision: 806039
- Sync with Fedora 21

* Tue Dec 02 2014 dmorgan <dmorgan> 4.1.0-10.mga5
+ Revision: 800278
- Disable this non-sense minimal check

* Mon Dec 01 2014 dmorgan <dmorgan> 4.1.0-9.mga5
+ Revision: 800219
- Rebuild because of removed packages

* Sat Nov 29 2014 cjw <cjw> 4.1.0-8.mga5
+ Revision: 799862
- add conflicts: python-pyxml because maven.prov doesnt work with this package installed
- add back maven-metadata

* Sat Nov 29 2014 cjw <cjw> 4.1.0-7.mga5
+ Revision: 799833
- do not build maven-related subpackages because of broken dependencies, they can be re-added later
- rebuild for task-obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Sun Nov 23 2014 luigiwalser <luigiwalser> 4.1.0-6.mga5
+ Revision: 798368
- do not require dropped httpcomponents-project

* Mon Nov 03 2014 philippem <philippem> 4.1.0-5.mga5
+ Revision: 795336
- enable tests

* Thu Oct 30 2014 pterjan <pterjan> 4.1.0-4.mga5
+ Revision: 794780
- Fix ivy-local dependency

* Thu Oct 30 2014 pterjan <pterjan> 4.1.0-3.mga5
+ Revision: 794765
- Drop fedora-review-plugin-java

* Thu Oct 30 2014 dmorgan <dmorgan> 4.1.0-2.mga5
+ Revision: 794685
- Rebuild after bootstrap
- New version
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps
+ pterjan <pterjan>
- 4.1.0
- Sync wiith fedora

* Sun Jun 15 2014 dmorgan <dmorgan> 3.4.1-1.mga5
+ Revision: 636288
- New version

* Sat May 31 2014 pterjan <pterjan> 3.4.0-12.mga5
+ Revision: 628272
- Rebuild for new Python

* Mon May 19 2014 dmorgan <dmorgan> 3.4.0-11.mga5
+ Revision: 623745
- Rebuild against java stack
- Revert to version 3.4.0
- New version

* Sun May 11 2014 dmorgan <dmorgan> 3.4.2-1.mga5
+ Revision: 621873
- New version 3.4.2

* Sun Jan 26 2014 dmorgan <dmorgan> 3.4.0-9.mga4
+ Revision: 568237
- Fix conflict against older maven

* Wed Dec 25 2013 dmorgan <dmorgan> 3.4.0-8.mga4
+ Revision: 560577
- Add one more common require

* Mon Dec 16 2013 dmorgan <dmorgan> 3.4.0-7.mga4
+ Revision: 557424
- Requires mvn(javax.mail:mail) in maven-local

* Tue Oct 22 2013 umeabot <umeabot> 3.4.0-6.mga4
+ Revision: 545411
- Mageia 4 Mass Rebuild
+ dmorgan <dmorgan>
- Remove provides not needed anymore

* Mon Oct 21 2013 dmorgan <dmorgan> 3.2.4-3.mga4
+ Revision: 540794
- More provides

* Mon Oct 21 2013 dmorgan <dmorgan> 3.2.4-2.mga4
+ Revision: 539855
- Bump release to rebuild
- Downgrade to version 3.2.4 to fix maven install/build

* Mon Oct 21 2013 dmorgan <dmorgan> 3.4.0-5.mga4
+ Revision: 537808
- Add back google-guice-sisu-guice-noaop demap

* Tue Oct 15 2013 dmorgan <dmorgan> 3.4.0-4.mga4
+ Revision: 501226
- New version

* Tue Oct 15 2013 dmorgan <dmorgan> 3.3.1-4.mga4
+ Revision: 500552
- Remove wrong patch

* Mon Oct 14 2013 pterjan <pterjan> 3.3.1-3.mga4
+ Revision: 497834
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 12 2013 dmorgan <dmorgan> 3.3.1-2.mga4
+ Revision: 495597
- Remove SYSTEM version provide

* Wed Oct 09 2013 dmorgan <dmorgan> 3.3.1-1.mga4
+ Revision: 493927
- New version 3.3.1

* Fri Sep 20 2013 dmorgan <dmorgan> 3.2.1-2.mga4
+ Revision: 482524
- Fix requires for xsltproc

* Fri Sep 20 2013 dmorgan <dmorgan> 3.2.1-1.mga4
+ Revision: 481757
- New version 3.2.1

* Fri Sep 20 2013 dmorgan <dmorgan> 3.1.2-1.mga4
+ Revision: 481667
- New version 3.1.2

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-3.mga4
+ Revision: 481583
- Obsolete/providesjava-rpmbuild

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-2.mga4
+ Revision: 481568
- More provides

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-1.mga4
+ Revision: 481562
- New version 3.1.1

* Thu Sep 19 2013 dmorgan <dmorgan> 3.0.2-2.mga4
+ Revision: 481442
- Obsolete jpackage-utils
- FIx file list

* Thu Sep 19 2013 dmorgan <dmorgan> 3.0.2-1.mga4
+ Revision: 481436
- New upstream major version 3.0.2

* Fri Jul 12 2013 dmorgan <dmorgan> 0.15.0-6.mga4
+ Revision: 453461
- Renable local scripts

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-5.mga4
+ Revision: 452558
- Enable debug by default

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-4.mga4
+ Revision: 452552
- Fix conflicts with maven

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-3.mga4
+ Revision: 452548
- Do not own fileattr dir

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-2.mga4
+ Revision: 452477
- Fix buildrequires

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-1.mga4
+ Revision: 452465
- New version

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-2.mga3
+ Revision: 399298
- Fix conflict with maven

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-1.mga3
+ Revision: 399281
- Fix release to 1

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-0.mga3
+ Revision: 399275
- New version
- New version 0.10.0

* Sat Jan 12 2013 umeabot <umeabot> 0.8.0-2.mga3
+ Revision: 354844
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 dmorgan <dmorgan> 0.8.0-1.mga3
+ Revision: 324009
- New version ( add maven-local package)

* Mon Sep 10 2012 dmorgan <dmorgan> 0.6.0-1.mga3
+ Revision: 291860
- Update to upstream version 0.6.0
- Make maven provides versioned
- Add additional pom_ macros to simplify additional pom editing

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-3.mga3
+ Revision: 268933
- Fix again conflict with rpm

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-2.mga3
+ Revision: 268929
- Remove wrong require

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-1.mga3
+ Revision: 268924
- New version

* Tue Jun 12 2012 dmorgan <dmorgan> 0.3.1-1.mga3
+ Revision: 260022
- imported package javapackages-tools


* Tue Mar  6 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.1-1
- Create maven provides from fragments instead of poms

* Thu Feb 16 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-3
- Fix maven_depmap installation

* Wed Feb 15 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-2
- Add conflicts with older jpackage-utils

* Wed Feb 15 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-1
- Initial version split from jpackage-utils

